import birl
import env
import gleam/int
import gleam/io
import gleam/option
import gleam_community/ansi
import spacetraders_sdk
import spacetraders_sdk/models/account_id
import spacetraders_sdk/models/agent_symbol
import spacetraders_sdk/models/faction_symbol
import spacetraders_sdk/models/waypoint_symbol

pub fn main() -> Nil {
  let assert Ok(env.Env(agent_token:, ..)) = env.load_dotenv()
  let assert Ok(server_status) = spacetraders_sdk.get_server_status()
  let assert Ok(account) = spacetraders_sdk.get_account(agent_token)
  let assert Ok(agent) = spacetraders_sdk.get_agent(agent_token)
  let now = birl.now()
  io.println("")
  io.println(ansi.bold(ansi.underline(ansi.blue("Account"))))
  io.println(ansi.bold("Id:\t\t") <> account_id.to_string(account.id))
  case account.email {
    option.Some(email) -> io.println(ansi.bold("Email:\t\t") <> email)
    option.None -> Nil
  }
  io.println(ansi.bold("Created At:\t") <> birl.to_iso8601(account.created_at))
  io.println("")
  io.println(ansi.bold(ansi.underline(ansi.magenta("Agent"))))
  io.println(ansi.bold("Symbol:\t\t") <> agent_symbol.to_string(agent.symbol))
  io.println(
    ansi.bold("Headquarters:\t")
    <> waypoint_symbol.to_string(agent.headquarters),
  )
  io.println(ansi.bold("Credits:\t") <> int.to_string(agent.credits))
  io.println(
    ansi.bold("Faction:\t") <> faction_symbol.to_string(agent.starting_faction),
  )
  io.println(ansi.bold("Ship Count:\t") <> int.to_string(agent.ship_count))
  io.println("")
  io.println(ansi.italic(
    "Server last reset "
    <> birl.legible_difference(now, server_status.reset_date),
  ))
  io.println(ansi.italic(
    "Server will next reset "
    <> birl.legible_difference(now, server_status.server_resets.next),
  ))
  io.println("")
}
